==========
metlog-cef
==========

metlog-cef is a plugin extension for `Metlog 
<http://github.com/mozilla-services/metlog-py>`.  metlog-cef
provides an extension to log send CEF messages to a logstash server.

More information about how Mozilla Services is using Metlog (including what is
being used for a router and what endpoints are in use / planning to be used)
can be found on the relevant `spec page
<https://wiki.mozilla.org/Services/Sagrada/Metlog>`_.
